@@ -1,7 +1,8 @@
 #include "prophesee.hpp"
 
 // event generator for Prophesee cameras
-Generator<AEDAT::PolarityEvent> prophesee_event_generator(
+Generator<AER::Event> prophesee_event_generator(
+    const std::atomic<bool> &runFlag,
     const std::optional<std::string> serial_number = std::nullopt) {
 
   Metavision::Camera cam;
@@ -15,26 +16,23 @@ Generator<AEDAT::PolarityEvent> prophesee_event_generator(
     }
   } catch (const std::exception &e) {
     if (serial_number.has_value()) {
-      std::cout << "Failure with serial number '" << serial_number.value()
+      std::cerr << "Failure with serial number '" << serial_number.value()
                 << "': " << e.what() << std::endl;
     } else {
-      std::cout << "Failure to identify Prophesee camera: " << e.what() << std::endl;
+      std::cerr << "Failure to identify Prophesee camera: " << e.what()
+                << std::endl;
     }
 
-    std::cout << "Available cameras: " << std::endl;
-
     Metavision::AvailableSourcesList available_systems =
         cam.list_online_sources();
 
     for (int i = 0;
          i < available_systems[Metavision::OnlineSourceType::USB].size(); i++) {
-      std::cout << "- "
+      std::cerr << "- "
                 << available_systems[Metavision::OnlineSourceType::USB][i]
                 << std::endl;
     }
 
-    std::cout << std::endl;
-
     throw std::invalid_argument(
         "Please choose one of the above listed serial numbers and run again!");
   }
@@ -54,12 +52,15 @@ Generator<AEDAT::PolarityEvent> prophesee_event_generator(
   cam.start();
 
   // keep running while camera is on or video is finished
-  while (cam.is_running()) {
+  while (cam.is_running() && runFlag.load()) {
     if ((ev_start != NULL) && (ev_final != NULL)) {
       // iterate over events in buffer and convert to AEDAT Polarity Event
       for (const Metavision::EventCD *ev = ev_start; ev < ev_final; ++ev) {
-        const AEDAT::PolarityEvent polarityEvent = {
-            (uint64_t)ev->t, ev->x, ev->y, true, (bool)ev->p,
+        const AER::Event polarityEvent = {
+            (uint64_t)ev->t,
+            ev->x,
+            ev->y,
+            (bool)ev->p,
         };
         co_yield polarityEvent;
       }
