@@ -1,10 +1,13 @@
 import multiprocessing
 import socket
 import time
+import pytest
 
-import torch
+import numpy
 from aestream import UDPInput
 
+from . import _has_cuda_torch
+
 
 def stream_fake_data(port):
     data = b"\x0F\x00\xDA\x00"
@@ -14,7 +17,7 @@ def stream_fake_data(port):
 
 
 def start_stream(port):
-    p = multiprocessing.Process(target=stream_fake_data, args=(port, ))
+    p = multiprocessing.Process(target=stream_fake_data, args=(port,))
     p.start()
     return p
 
@@ -25,31 +28,33 @@ def test_udp():
 
         interval = 0.5
         t_0 = time.time()
-        time.sleep(0.5)
         while True:
             if t_0 + interval <= time.time():
                 frame = stream.read()
                 break
-
-    assert torch.eq(frame[218, 15], 1)
+    assert numpy.equal(frame[218, 15], 1)
 
 
+@pytest.mark.skipif(not _has_cuda_torch(), reason="Torch-gpu is not installed")
 def test_udp_gpu():
-    if (torch.has_cuda):
+    import torch
+
+    if torch.has_cuda:
         with UDPInput((640, 480), device="cuda", port=3334) as stream:
             start_stream(3334)  # Start streaming from file
 
             interval = 0.5
-            t_0 = time.time()
             time.sleep(0.5)
+            t_0 = time.time()
             while True:
                 if t_0 + interval <= time.time():
                     frame = stream.read()
+                    print(frame.argmax(0).argmax(), frame.argmax(1).argmax())
                     break
 
-        print(frame[218, 15])
         assert torch.eq(frame[218, 15], 1)
 
+
 if __name__ == "__main__":
     test_udp()
     test_udp_gpu()
