@@ -4,8 +4,7 @@
 #include <thread>
 #include <unistd.h>
 
-#include <torch/extension.h>
-#include <torch/torch.h>
+#include "types.hpp"
 
 #include "tensor_buffer.hpp"
 #include "udp_client.hpp"
@@ -21,16 +20,16 @@ private:
 
 public:
   uint64_t count = 0;
-  UDPInput(torch::IntArrayRef shape, torch::Device device, int port)
+  UDPInput(py_size_t shape, const std::string &device, int port)
       : buffer(shape, device, max_events_per_packet), port(port) {}
 
-  UDPInput *start_server() {
+  UDPInput *start_stream() {
     std::thread socket_thread(&UDPInput::serve_synchronous, this);
     socket_thread.detach();
     return this;
   }
 
-  at::Tensor read() { return buffer.read(); }
+  BufferPointer read() { return buffer.read(); }
 
   void serve_synchronous() {
     int sockfd;
@@ -58,5 +57,7 @@ public:
     close(sockfd);
   }
 
-  void stop_server() { is_serving.store(false); }
+  void stop_stream(nb::object &a, nb::object &b, nb::object &c) {
+    is_serving.store(false);
+  }
 };
